@@ -9,6 +9,8 @@ that handle direct requests to the GWOSC host.
 
 import logging
 import os
+import re
+from urllib.parse import urlencode
 
 import requests
 
@@ -28,9 +30,11 @@ DEFAULT_URL = "https://www.gw-openscience.org"
 #: Cache of downloaded blobs
 JSON_CACHE = {}
 
+_ALLOWED_OPS = set((">=", "=>", "<=", "=<"))
 
 # -- JSON handling ------------------------------------------------------------
 
+
 def fetch_json(url, **kwargs):
     """Fetch JSON data from a remote URL
 
@@ -58,15 +62,11 @@ def fetch_json(url, **kwargs):
     except KeyError:
         logger.debug("fetching {}".format(url))
         resp = requests.get(url, **kwargs)
-        try:
-            return JSON_CACHE.setdefault(
-                url,
-                resp.json(),
-            )
-        except ValueError as exc:
-            exc.args = ("Failed to parse GWOSC JSON from %r: %s"
-                        % (url, str(exc)),)
-            raise
+        resp.raise_for_status()
+        return JSON_CACHE.setdefault(
+            url,
+            resp.json(),
+        )
 
 
 # -- Run datasets -------------------------------------------------------------
@@ -136,6 +136,14 @@ def fetch_run_json(run, detector, gpsstart=0, gpsend=_MAX_GPS,
 
 # -- EventAPI catalogs -------------------------------------------------------
 
+def _allowed_params_url(host=DEFAULT_URL):
+    return "{}/eventapi/json/query/params/".format(host)
+
+
+def fetch_allowed_params_json(host=DEFAULT_URL):
+    return fetch_json(_allowed_params_url(host=host))
+
+
 def _eventapi_url(full=False, host=DEFAULT_URL):
     j = "jsonfull" if full else "json"
     return "{}/eventapi/{}/".format(host, j)
@@ -275,6 +283,124 @@ def _fetch_allevents_event_json(
     raise ValueError(msg)
 
 
+def _parse_two_ops(compiled_m, host=DEFAULT_URL):
+    allowed_params = fetch_allowed_params_json(host=host)
+    md = compiled_m.groupdict()
+    op1, op2 = md["op1"], md["op2"]
+    if not set((op1, op2)).issubset(_ALLOWED_OPS):
+        raise ValueError(
+            "Could not parse select string.\n"
+            "Unknown operators."
+        )
+    param, val1, val2 = md["param"], md["val1"], md["val2"]
+    if param not in allowed_params:
+        raise ValueError(
+            "Could not parse select string.\n"
+            f"Unrecognized parameter: {param}.\n"
+            f"Use one of:\n{allowed_params}"
+        )
+    queries = []
+    if ">" in op1:
+        queries.append((f"max-{param}", val1))
+    if "<" in op1:
+        queries.append((f"min-{param}", val1))
+    if ">" in op2:
+        queries.append((f"min-{param}", val2))
+    if "<" in op2:
+        queries.append((f"max-{param}", val2))
+    return queries
+
+
+def _parse_one_op(compiled_m, host=DEFAULT_URL):
+    allowed_params = fetch_allowed_params_json(host=host)
+    md = compiled_m.groupdict()
+    op = md["op"]
+    if not set((op,)).issubset(_ALLOWED_OPS):
+        raise ValueError(
+            "Could not parse select string.\n"
+            "Unknown operator."
+        )
+    param, val = md["param"], md["val"]
+    if param not in allowed_params:
+        raise ValueError(
+            f"Could not parse select string.\n"
+            f"Unrecognized parameter: {param}.\n"
+            f"Use one of:\n{allowed_params}"
+        )
+    queries = []
+    if ">" in op:
+        queries.append((f"min-{param}", val))
+    if "<" in op:
+        queries.append((f"max-{param}", val))
+    return queries
+
+
+def _select_to_query(select, host=DEFAULT_URL):
+    """Parse select string and translate into URL GET parameters"""
+
+    # Captures strings of the form `1.44 <= param <= 5.0`
+    two_ops = re.compile(
+        r"^\s*(?P<val1>[\d.+-eE]+)\s*(?P<op1>[<>=]{2})\s*(?P<param>[\w-]+)"
+        r"\s*(?P<op2>[<>=]+)\s*(?P<val2>[\d.+-eE]+)\s*$"
+    )
+    # Captures strings of the form `param <= 5.0`
+    one_op = re.compile(
+        r"^\s*(?P<param>[\w-]+)\s*(?P<op>[<>=]{2})\s*(?P<val>[\d.+-eE]+)\s*$"
+    )
+
+    queries = []
+    for s in select:
+        for regex, _parse in (
+            (one_op, _parse_one_op),
+            (two_ops, _parse_two_ops),
+        ):
+            m = regex.match(s)
+            if m is not None:
+                queries.extend(_parse(m, host=host))
+                break
+        else:
+            raise ValueError(f"Could not parse select string: {s}")
+    return urlencode(queries)
+
+
+def _query_events_url(select, host=DEFAULT_URL):
+    return "{}/eventapi/json/query/show?{}".format(
+        host, _select_to_query(select, host=host)
+    )
+
+
+def fetch_filtered_events_json(select, host=DEFAULT_URL):
+    """"Return the JSON metadata for the events constrained by select
+
+    Parameters
+    ----------
+    select : `list-like`
+        a list of range constrains for the events.
+        All ranges should have inclusive ends (<= and >= operators).
+
+    host : `str`, optional
+        the URL of the GWOSC host to query, defaults to
+        https://www.gw-openscience.org
+
+    Returns
+    -------
+    data : `dict` or `list`
+        the JSON data retrieved from GWOSC and returnend by
+        :meth:`requests.Response.json`
+
+    Example
+    -------
+    >>> fetch_filtered_events_json(
+    ...     select=[
+    ...         "mass-1-source <= 5",
+    ...         "mass-2-source =< 10",
+    ...         "10 <= luminosity-distance <= 100",
+    ...     ]
+    ... )
+    """
+    return fetch_json(_query_events_url(select, host=host))
+
+
 def _event_url(
         event,
         catalog=None,
@@ -325,32 +451,3 @@ def fetch_event_json(
     return fetch_json(
         _event_url(event, catalog=catalog, version=version, host=host),
     )
-
-
-# -- legacy
-
-def _legacy_catalog_url(catalog, host=DEFAULT_URL):
-    return "{}/catalog/{}/filelist/".format(
-        host, catalog,
-    )
-
-
-def fetch_legacy_catalog_json(catalog, host=DEFAULT_URL):
-    """"Returns the JSON metadata for the given catalogue
-
-    Parameters
-    ----------
-    catalog : `str`
-        the name of the event catalog, e.g. `GWTC-1-confident`
-
-    host : `str`, optional
-        the URL of the GWOSC host to query, defaults to
-        https://www.gw-openscience.org
-
-    Returns
-    -------
-    json
-        the JSON data retrieved from GWOSC and returnend by
-        :meth:`requests.Response.json`
-    """
-    return fetch_json(_legacy_catalog_url(catalog, host=host))
