@@ -28,6 +28,12 @@ Similar queries are available for observing run datasets:
 (1126051217, 1137254417)
 >>> datasets.run_at_gps(1135136350)  # event_gps('GW151226')
 'O1'
+
+To run an event query filtered by merger parameters:
+
+>>> from gwosc.datasets import query_events
+>>> query_events(select=["mass-1-source <= 3.0"])
+['GW170817-v3', 'GW190425-v1', 'GW190425-v2', 'GW190425_081805-v3']
 """  # noqa: E501
 
 import re
@@ -590,3 +596,61 @@ def dataset_type(dataset, host=api.DEFAULT_URL):
     raise ValueError(
         "failed to determine type for dataset {0!r}".format(dataset),
     )
+
+
+def query_events(select, host=api.DEFAULT_URL):
+    """Return a list of events filtered by the parameters in `select`
+
+    Parameters
+    ----------
+    select : `list` of `str`
+        A list of strings where each element is a range constrain on the
+        event parameters.
+        All ranges should have inclusive ends (<= and => operators).
+
+    host : `str`, optional
+        the URL of the GWOSC host to query
+
+    Examples
+    --------
+    >>> from gwosc.datasets import query_events
+    >>> query_events(
+    ...     select=[
+    ...         "mass-1-source >= 1.4",
+    ...         "200 >= luminosity-distance >= 100",
+    ...     ]
+    ... )
+    ['GW190425-v1', 'GW190425-v2', 'GW190425_081805-v3']
+
+    Notes
+    -----
+    Operators:
+
+    - `<=` (or `=<`)
+    - `=>` (or `>=`)
+
+    Parameters:
+
+    - ``gps-time`,
+    - ``mass-1-source``,
+    - ``mass-2-source``,
+    - ``network-matched-filter-snr``,
+    - ``luminosity-distance``,
+    - ``chi-eff``,
+    - ``total-mass-source``,
+    - ``chirp-mass``,
+    - ``chirp-mass-source``,
+    - ``redshift``,
+    - ``far``,
+    - ``p-astro``,
+    - ``final-mass-source``
+
+    For a full description of all parameters see
+    https://www.gwosc.org/apidocs/#event5
+    """
+    return list(
+        api.fetch_filtered_events_json(
+            select=select,
+            host=host,
+        )["events"].keys()
+    )
